@@ -3,19 +3,8 @@
 """
 Copyright (C) 2010-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 import os
@@ -24,8 +13,6 @@ import subprocess
 import datetime
 from io import BytesIO
 from hashlib import md5
-if os.name == 'nt':
-    import winsound  # pylint: disable=import-error
 
 from common import Debug, Internal, StrMixin, cacheDir
 from util import which, removeIfExists, uniqueList, elapsedSince
@@ -45,6 +32,9 @@ from tile import Tile
         # self.audio.enqueue(Phonon.MediaSource(wavName))
         # self.audio.play()
 
+if os.name == 'nt':
+    import winsound  # pylint: disable=import-error
+
 
 class Sound:
 
@@ -57,7 +47,7 @@ class Sound:
 
     @staticmethod
     def findOggBinary():
-        """sets __oggBinary to exe name or an empty string"""
+        """set __oggBinary to exe name or an empty string"""
         if Sound.__oggBinary is None:
             if os.name == 'nt':
                 Sound.__oggBinary = os.path.join('share', 'kajongg', 'voices', 'oggdec.exe')
@@ -189,7 +179,7 @@ class Voice(StrMixin):
     destination, no tarfile is written, only the content. It makes
     only sense to cache the voice in a tarfile at source."""
 
-    __availableVoices = None
+    __availableVoices = []
     md5sumLength = 32 # magical constant
 
     def __init__(self, directory, content=None):
@@ -243,8 +233,7 @@ class Voice(StrMixin):
             group = Internal.kajonggrc.group('Locale')
             prefLanguages = uniqueList(
                 ':'.join(['local', str(group.readEntry('Language')), 'en_US']).split(':'))
-            prefLanguages = dict((x[1], x[0])
-                                 for x in enumerate(prefLanguages))
+            prefLanguages = dict(enumerate(prefLanguages))
             result = sorted(
                 result, key=lambda x: prefLanguages.get(x.language(), 9999))
             if Debug.sound:
@@ -254,7 +243,7 @@ class Voice(StrMixin):
 
     @staticmethod
     def locate(name):
-        """returns Voice or None if no foreign or local voice matches.
+        """return Voice or None if no foreign or local voice matches.
         In other words never return a predefined voice"""
         for voice in Voice.availableVoices():
             dirname = os.path.split(voice.directory)[-1]
@@ -264,7 +253,7 @@ class Voice(StrMixin):
                         'locate found %s by md5sum in %s' %
                         (name, voice.directory))
                 return voice
-            elif name == dirname and voice.language() == 'local':
+            if name == dirname and voice.language() == 'local':
                 if Debug.sound:
                     logDebug(
                         'locate found %s by name in %s' %
@@ -272,6 +261,7 @@ class Voice(StrMixin):
                 return voice
         if Debug.sound:
             logDebug('Personal sound for %s not found' % (name))
+        return None
 
     def buildSubvoice(self, oggName, side):
         """side is 'left' or 'right'."""
@@ -327,6 +317,7 @@ class Voice(StrMixin):
         """a list of all found ogg files"""
         if os.path.exists(self.directory):
             return sorted(x for x in os.listdir(self.directory) if x.endswith('.ogg'))
+        return []
 
     def __computeMd5sum(self):
         """update md5sum file. If it changed, return True.
@@ -362,7 +353,7 @@ class Voice(StrMixin):
                         (existingMd5sum, md5Name, self.__md5sum))
             try:
                 open(md5Name, 'w').write('%s\n' % self.__md5sum)
-            except BaseException as exception:
+            except OSError as exception:
                 logException(
                     '\n'.join([i18n('cannot write <filename>%1</filename>: %2',
                                     md5Name,
@@ -398,16 +389,16 @@ class Voice(StrMixin):
         return os.path.join(self.directory, 'md5sum')
 
     def savedmd5Sum(self):
-        """returns the current value of the md5sum file"""
+        """return the current value of the md5sum file"""
         if os.path.exists(self.md5FileName()):
             try:
                 line = open(self.md5FileName(), 'r').readlines()[0].replace(' -', '').strip()
                 if len(line) == self.md5sumLength:
                     return line
-                else:
-                    logWarning('{} has wrong content: {}'.format(self.md5FileName(), line))
-            except BaseException as exc:
+                logWarning('{} has wrong content: {}'.format(self.md5FileName(), line))
+            except OSError as exc:
                 logWarning('{} has wrong content: {}'.format(self.md5FileName(), exc))
+        return None
 
     @property
     def md5sum(self):
@@ -435,6 +426,7 @@ class Voice(StrMixin):
         self.__buildArchive()
         if os.path.exists(self.archiveName()):
             return open(self.archiveName(), 'rb').read()
+        return None
 
     @archiveContent.setter
     def archiveContent(self, content):
